@@ -39,11 +39,11 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         self.stdout.write(self.style.SUCCESS('Start Bakery build'))
+        vb = VersionBuild.get()
+        vb.minor()
         self.set_options(*args, **options)
         self.init_build_dir()
         self.build_views()
-        vb = VersionBuild.get()
-        vb.minor()
         self.stdout.write(self.style.SUCCESS('Build finished'))
 
     def set_options(self, *args, **options):
@@ -66,8 +66,10 @@ class Command(BaseCommand):
     def init_build_dir(self):
         self.stdout.write(self.style.SUCCESS("Initializing %s" % self.build_dir))
         if self.fs.exists(self.build_dir):
-            self.fs.removetree(self.build_dir)
-        self.fs.makedirs(self.build_dir)
+            pass
+            #   self.fs.removetree(self.build_dir)
+        else:
+            self.fs.makedirs(self.build_dir)
 
     def get_view_instance(self, view):
         return view()
